import getDataAA
import numpy as np
import os

def run():
    print('Scanner de millas AA iniciado...')

    data = getDataAA.get()

    pMiles = np.array(data.millas[0]) # clase promocional
    tMiles = np.array(data.millas[0]) # clase turista
    bMiles = np.array(data.millas[0]) # clase busines

    pMiles[pMiles == 'N/A'] = '-1'
    tMiles[tMiles == 'N/A'] = '-1'
    bMiles[bMiles == 'N/A'] = '-1'

    pMiles = pMiles.astype(np.float)
    tMiles = tMiles.astype(np.float)
    bMiles = bMiles.astype(np.float)

    # chequeo si existen las tablas anteriores. Sino uso las actuales y las guardo.
    if os.path.isfile('pMiles_old.npy'):
        pMiles_old = np.load('pMiles_old.npy')
    else:
        pMiles_old = pMiles
        np.save('pMiles_old.npy', pMiles)

    if os.path.isfile('tMiles_old.npy'):
        tMiles_old = np.load('tMiles_old.npy')
    else:
        tMiles_old = tMiles
        np.save('tMiles_old.npy', tMiles)

    if os.path.isfile('bMiles_old.npy'):
        bMiles_old = np.load('bMiles_old.npy')
    else:
        bMiles_old = bMiles
        np.save('bMiles_old.npy', bMiles)

    if bool((pMiles-pMiles_old).any()) or bool((tMiles-tMiles_old).any()) or bool((bMiles-bMiles_old).any()):
        print('\n¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡¡')
        print('Hay cambio en la tabla de Millas.')
        print('!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n')
        print('Reemplazar tabla anterior de millas? ')
        
        val = input('(S/N): ')
        if val == 'S' or val == 's':
            np.save('pMiles_old.npy', pMiles)
            np.save('tMiles_old.npy', tMiles)
            np.save('bMiles_old.npy', bMiles)
    else:
        print('No cambio en la tabla de Millas.')
        val = 'N'
    #print('Escanear nuevamente?')
    #val = input('(S/N): ')
    return val
    





from AAmiles import app

if __name__ == '__main__':
    val = 'S'
    while val == 'S' or val == 's':
        try:
            val = app.run()
        except:
            print('Intentar nuevamente?')
            val = input('(S/N) :')


from distutils.core import setup

setup(
  name = 'AAmiles',         
  packages = ['AAmiles','AAmiles/getDataAA'],  
  version = '0.1.2',     
  license='MIT',       
  description = 'Check changes in the miles required to obtain a ticket from the AA web page',
  long_description = open('README.md', 'r').read() ,
  long_description_content_type='text/markdown',
  author = 'Aldebaran bO',  
  author_email = '19.beta.Orionis@gmail.com',   
  url = 'https://github.com/bOrionis/AAmiles',  
  download_url = 'https://github.com/bOrionis/AAmiles', 
  keywords = ['Miles', 'airplane tickets', 'Aerolineas Argentinas'],  
  install_requires=[        
          'request',
          'bs4',
          'numpy',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha', 
    'Intended Audience :: End Users/Desktop',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',    
  ],
)




import requests
from bs4 import BeautifulSoup
import os

class get:

    def __init__(self):
        '''Descarga la tabla de millas de AA.

        Uso:

        import getDataAA

        data = getDataAA.get()

        data.millas # lista con los valores de millas. 
        data.titles # lista con los titulos de las tablas
        data.destinos # lista con los destinos de las millas

        '''

        headers = {"User-Agent": 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.129 Safari/537.36'}

        URL = 'https://www.aerolineas.com.ar/es-ar/aerolineas_plus/disfrutatusmillas'

        self.headers = headers
        self.URL = URL
        
        try:
            self.page = requests.get(self.URL, headers=self.headers)
            self.soup = BeautifulSoup(self.page.content, 'html.parser')

            self.getTitles(['panel-body','table-left-fixed'])
            self.getTables(['table-left-fixed'])
        except ConnectionError:
            print("No hay conexion a internet.")
        except:
            print("Error. Verificar conexion de red.")
                  
    def getTitles(self, clss):
        self.titles = []
        for cl in clss:
            table = self.soup.findAll('div', {'class': cl})
            for tabla in table:
                if tabla.find('h4'):
                    self.titles.append(tabla.find('h4').text.strip())

    def getDestinos(self,tabla, encabezado, row):
    
        destinos = []
        subtable = tabla.find(encabezado)
        rw = subtable.find_all(row)
        destinos = [ele.text.strip() for ele in rw]
        self.destinos.append(destinos)

    def getMillas(self, tabla, encabezado, rowID, colID):
        
        millas = []
        subtable = tabla.find(encabezado)
        rows = subtable.find_all(rowID)
        for row in rows:
            cols = row.find_all(colID)
            cols = [ele.text.strip() for ele in cols]
            millas.append([ele for ele in cols if ele])
        self.millas.append(millas)

    def getTables(self, clss):
        self.destinos = []
        self.millas = []
        for cl in clss:
            table = self.soup.findAll('div', {'class': cl})
            for tabla in table:
                self.getDestinos(tabla,'thead','th')
                self.getMillas(tabla,'tbody','tr','td')